---
name: Feature request
about: Suggest an idea for capa

---
<!--
# Is your issue related to capa rules (for example an idea for a new rule)?
We use submodules to separate code, rules and test data. If your issue is related to capa rules, please report it at https://github.com/mandiant/capa-rules/issues.

# Have you checked that your issue isn't already filed?
Please search if there is a similar issue at https://github.com/mandiant/capa/issues. If there is already a similar issue, please add more details there instead of opening a new one.

# Have you read capa's Code of Conduct?
By filing an Issue, you are expected to comply with it, including treating everyone with respect: https://github.com/mandiant/capa/blob/master/.github/CODE_OF_CONDUCT.md

# Have you read capa's CONTRIBUTING guide?
It contains helpful information about how to contribute to capa. Check https://github.com/mandiant/capa/blob/master/.github/CONTRIBUTING.md#suggesting-enhancements
-->

### Summary

<!-- One paragraph explanation of the feature. -->

### Motivation

<!-- Why are we doing this? What use cases does it support? What is the expected outcome? -->

### Describe alternatives you've considered

<!-- A clear and concise description of the alternative solutions you've considered. -->

## Additional context

<!-- Add any other context or screenshots about the feature request here. -->
